# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-IPC-Run3
Version:	0.049
Release:	1.%{__distinit}%{__distvers}
Summary:	Run a sub-process in batch mode (à la system) on Unix, Win32, etcetera
License:	(GPL-1.0-or-later OR Artistic-1.0-Perl) OR BSD-2-Clause
URL:		https://metacpan.org/release/IPC-Run3
Source0:	https://cpan.metacpan.org/modules/by-module/IPC/IPC-Run3-%{version}.tar.gz
Patch0:		0001-test-and-fix-for-RT-52317-Calling-run3-garbles-STDIN.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(strict)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(bytes)
BuildRequires:	perl(Config)
BuildRequires:	perl(Test)
BuildRequires:	perl(Test::More) >= 0.31
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Getopt::Long)
Requires:	perl(Time::HiRes)

%description
This module allows you to run a sub-process and redirect stdin, stdout,
and/or stderr to files and perl data structures. It aims to satisfy 99% of
the need for using system, qx, and open3 with a simple, extremely Perlish
API and none of the bloat and rarely used features of IPC::Run.

%prep
%setup -q -n IPC-Run3-%{version}

# https://rt.cpan.org/Public/Bug/Display.html?id=52317
# http://bugzilla.redhat.com/1062267
# Patch based on
# https://github.com/rschupp/IPC-Run3/commit/8ebe48760cfdc78fbf4fc46413dde9470121b99e
%patch -P 0 -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test RELEASE_TESTING=1

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/IPC/
%{_mandir}/man3/IPC::Run3.3*
%{_mandir}/man3/IPC::Run3::ProfArrayBuffer.3*
%{_mandir}/man3/IPC::Run3::ProfLogReader.3*
%{_mandir}/man3/IPC::Run3::ProfLogger.3*
%{_mandir}/man3/IPC::Run3::ProfPP.3*
%{_mandir}/man3/IPC::Run3::ProfReporter.3*

%changelog
* Sun Jan 21 2024 Paul Howarth <paul@city-fan.org> - 0.049-1
- Update to 0.049
  - Avoid some uninitialized warnings in ProfLogReader
  - Improve errno handling on Windows
  - Avoid leaking fds
  - Fix typos in docs

* Mon Jul 17 2023 Paul Howarth <paul@city-fan.org> - 0.048-28
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax
- Use %%license unconditionally

* Fri Jun  7 2019 Paul Howarth <paul@city-fan.org> - 0.048-16
- Perl 5.30 rebuild

* Sat Apr 28 2018 Paul Howarth <paul@city-fan.org> - 0.048-12
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Wed Aug 31 2016 Paul Howarth <paul@city-fan.org> - 0.048-8
- Add test and fix for CPAN RT#52317: Calling run3 garbles STDIN (#1062267)
- Classify buildreqs by usage
- Simplify find command using -delete

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 0.048-3
- Use %%license where possible

* Sat Mar 29 2014 Paul Howarth <paul@city-fan.org> - 0.048-1
- Update to 0.048
  - Handle system() returning == 0xFF00 on Win32
  - Use Win32::ShellQuote for shell quoting on Win32
  - Update bugtracker and repo links
- Drop %%defattr, redundant since rpm 4.4

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 0.046-2
- Perl 5.18 rebuild

* Wed Jun 12 2013 Paul Howarth <paul@city-fan.org> - 0.046-1
- Update to 0.046
  - Replace a die with a croak
  - Typo fixes in documentation

* Fri Jun 29 2012 Paul Howarth <paul@city-fan.org> - 0.045-2
- BR:/R: perl(Getopt::Long)
- BR: perl(constant), perl(Exporter), perl(File::Temp), perl(Test) and
  perl(Test::More)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sat Dec 24 2011 Paul Howarth <paul@city-fan.org> - 0.045-1
- Update to 0.045
  - Skip a test that tickles an OpenBSD bug and hangs the process
- BR: perl(Carp)

* Mon Jun 27 2011 Paul Howarth <paul@city-fan.org> - 0.044-4
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Aug 23 2010 Paul Howarth <paul@city-fan.org> - 0.044-1
- Update to 0.044
  - Ignore user-defined __DIE__ handler in _type
  - Added test for __DIE__ handler behaviour
- No longer need to fix permissions of upstream files

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.043-4
- Rebuild for perl 5.12.1 in Rawhide

* Fri Jun  4 2010 Paul Howarth <paul@city-fan.org> - 0.043-3
- Fix dist tag for RHEL-6 Beta

* Fri Feb 26 2010 Paul Howarth <paul@city-fan.org> - 0.043-2
- Dist tag for Rawhide no longer needs special-casing

* Mon Jun  1 2009 Paul Howarth <paul@city-fan.org> - 0.043-1
- Update to 0.043 (META.yml updates)
- New upstream maintainer -> URL changes

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 0.042-3
- Import from Fedora

* Thu Aug 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.042-2
- Fix license tag (technically, it was correct before, but this keeps rpmlint from
  flagging this package as a false positive)

* Mon Aug 25 2008 Ralf Corsépius <corsepiu@fedoraproject.org> 0.042-1
- Upstream update

* Fri Aug 08 2008 Ralf Corsépius <rc040203@freenet.de> 0.041-1
- Upstream update

* Thu May 22 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.040-5
- Reorder license tag so it doesn't flag as a false positive

* Thu Feb 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.040-4
- Rebuild normally, second pass

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.040-3
- Rebuild for perl 5.10 (again), disable tests for first pass

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.040-2
- Rebuild normally, second pass

* Sat Jan 12 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.040-1.1
- Rebuild for new perl, disable tests and TPC for first pass

* Fri Dec 28 2007 Ralf Corsépius <rc040203@freenet.de> 0.040-1
- Upstream update
- chmod -x files from source tarball

* Tue Nov 27 2007 Ralf Corsépius <rc040203@freenet.de> 0.039-2
- Bump release to please koji suckage

* Tue Nov 27 2007 Ralf Corsépius <rc040203@freenet.de> 0.039-1
- Upstream update

* Fri Sep 07 2007 Ralf Corsépius <rc040203@freenet.de> 0.037-2
- Initial import
- Update license tag

* Tue Aug 07 2007 Ralf Corsépius <rc040203@freenet.de> 0.037-1
- Initial submission
